==> xclass_sdk-1.6.0.tar.gz: xclass_sdk-1.6.0/src/xclass_sdk/general_app.py <==
import json
import requests
from .xclass_helpers import multipartify


class Output:
    label = 'Output'
    text = ''
    def __init__(self, label):
        self.label = label
class Input:
    lable = 'Input'
    text = ''
    def __init__(self, label):
        self.lable = label
    def value(self):
        return 1
    
class GeneralApp:
    __apiKey = None
    __API_PATH = "https://ptn4du8158.execute-api.ap-southeast-1.amazonaws.com/dev/general-app"
    name='General app'
    description = 'Default description'
    author='Andrew'
    appLogo= 'https://uploads-ssl.webflow.com/64b02318b9d14ab16e20227a/64b3fda42fdf5ab7222c5a80_logo-xclass.png'
    okButton={
        'text':'Generate',
        'color': '#ea850c',
        'background':'linear-gradient(to bottom right, #ffedd5, #fdba74)',
    }
    resetButton={
        'text':'Reset',
        'color': '#000000',
        'background':'#EFEFEF',
    }
    def __init__(self, api_key):
        self.__apiKey = api_key
        self.listInput = []
        self.listOutput = []
    def createInput(self, prompt, type):
        self.listInput.append({
        'id': f'id-input-{len(self.listInput)}',
        'label': prompt,
        'type': type
        })
        return Input(prompt)
    def createOutput(self, prompt):
        self.listOutput.append({
        'id': f'id-output-{len(self.listOutput)}',
        'label': prompt,
        })
        return Output(prompt)
    
    def display(self, output, text):
        return 0
    
    def build(self, filePath):
        url = self.__API_PATH
        headers = {
            'api-key': self.__apiKey,
        }
        with open(filePath, 'r') as file:
            content = file.read()
            data = {
                'inputs': json.dumps(self.listInput),
                'outputs':json.dumps(self.listOutput),
                'content': content,
                'okButton': json.dumps(self.okButton),
                'resetButton': json.dumps(self.resetButton),
                'name': self.name,
                'description': self.description,
                'appLogo': self.appLogo,
                'author': self.author
            }
            response = requests.post(
                url, files=multipartify(data), headers=headers)
            print(response.json())

==> xclass_sdk-1.6.1.tar.gz: xclass_sdk-1.6.1/src/xclass_sdk/general_app.py <==
import json
import requests
from .xclass_helpers import multipartify


class Output:
    label = 'Output'
    text = ''
    def __init__(self, label):
        self.label = label
class Input:
    lable = 'Input'
    text = ''
    def __init__(self, label):
        self.lable = label
    def value(self):
        return 1
    
class GeneralApp:
    __apiKey = None
    __API_PATH = "https://ptn4du8158.execute-api.ap-southeast-1.amazonaws.com/dev/general-app"
    name='General app'
    description = 'Default description'
    author='Andrew'
    appLogo= 'https://uploads-ssl.webflow.com/64b02318b9d14ab16e20227a/64b3fda42fdf5ab7222c5a80_logo-xclass.png'
    okButton={
        'text':'Generate',
        'color': '#ea850c',
        'background':'linear-gradient(to bottom right, #ffedd5, #fdba74)',
    }
    resetButton={
        'text':'Reset',
        'color': '#000000',
        'background':'#EFEFEF',
    }
    def __init__(self, api_key):
        self.__apiKey = api_key
        self.listInput = []
        self.listOutput = []
    def createInput(self, prompt, type):
        self.listInput.append({
        'id': f'id-input-{len(self.listInput)}',
        'label': prompt,
        'type': type
        })
        return Input(prompt)
    def createOutput(self, prompt):
        self.listOutput.append({
        'id': f'id-output-{len(self.listOutput)}',
        'label': prompt,
        })
        return Output(prompt)
    
    def display(self, output, text):
        return 0
    
    def build(self, filePath):
        url = self.__API_PATH
        headers = {
            'api-key': self.__apiKey,
        }
        try:
            with open(filePath, 'r', encoding='utf-8') as file:
                content = file.read()
                data = {
                    'inputs': json.dumps(self.listInput),
                    'outputs':json.dumps(self.listOutput),
                    'content': content,
                    'okButton': json.dumps(self.okButton),
                    'resetButton': json.dumps(self.resetButton),
                    'name': self.name,
                    'description': self.description,
                    'appLogo': self.appLogo,
                    'author': self.author
                }
                response = requests.post(
                    url, files=multipartify(data), headers=headers)
                print(response.json())
        except Exception as e:
            print("An error occurred:", e)
